@@ -1294,7 +1294,7 @@ size_callback (GtkWidget * widget, gpointer data)
   GtkWidget *size_radio, *content_area, *label;
 
   game_size = g_settings_get_int (settings, KEY_SIZE);
-  if (pref_dialog_done && game_size != data && !restart_game_dialog) {
+  if (pref_dialog_done && game_size != GPOINTER_TO_INT (data) && !restart_game_dialog) {
     GtkDialogFlags flags = GTK_DIALOG_DESTROY_WITH_PARENT;
 
     restart_game_dialog = gtk_message_dialog_new (GTK_WINDOW (pref_dialog),
@@ -1591,6 +1591,8 @@ startup_cb (GApplication *application)
                                    app_actions, G_N_ELEMENTS (app_actions),
                                    application);
 
+  gtk_application_add_accelerator (GTK_APPLICATION (application), "<Primary>N", "app.new-game", NULL);
+
   settings = g_settings_new ("org.gnome.five-or-more");
 
   highscores = games_scores_new ("five-or-more",
